Sorting and searching
=====================

.. currentmodule:: numpy

Sorting
-------
.. autosummary::
   :toctree: generated/

   sort
   lexsort
   argsort
   ndarray.sort
   msort
   sort_complex

Searching
---------
.. autosummary::
   :toctree: generated/

   argmax
   nanargmax
   argmin
   nanargmin
   argwhere
   nonzero
   flatnonzero
   where
   searchsorted
   extract
